/****************************************************************************
*  This file is part of the sam3 port for the TNKernel RTOS
*
*  Copyright (c) 2009 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
*****************************************************************************
*  History:
*
*  26.09.2009  mifi   First Version
****************************************************************************/
#if !defined(__TN_PORT_SAM3_H__) && defined(TN_ARCH_CM3) && defined(TN_PORT_SAM3)
#define __TN_PORT_SAM3_H__

/***************************************************************************/
/*  DEFINE: All Structures and Commn Constants                             */
/***************************************************************************/

/*
 * Define the irq id and prio type, this makes it easier
 * if it must changed e.g. from unsigned char to unsigned short.
 */
typedef unsigned char         TN_IRQ_ID;
typedef unsigned char         TN_IRQ_PRIO;

/*
 * The sam3 suports 30 irq's with 16 priority levels.
 */
#define TN_MAX_IRQ_ID         30
#define TN_MAX_IRQ_PRIO       16

#define SUPC_IrqHandler_ID    0
#define RSTC_IrqHandler_ID    1
#define RTC_IrqHandler_ID     2
#define RTT_IrqHandler_ID     3
#define WDT_IrqHandler_ID     4
#define PMC_IrqHandler_ID     5
#define EFC0_IrqHandler_ID    6
#define EFC1_IrqHandler_ID    7
#define DBGU_IrqHandler_ID    8
#define HSMC4_IrqHandler_ID   9
#define PIOA_IrqHandler_ID    10
#define PIOB_IrqHandler_ID    11
#define PIOC_IrqHandler_ID    12
#define USART0_IrqHandler_ID  13
#define USART1_IrqHandler_ID  14
#define USART2_IrqHandler_ID  15
#define USART3_IrqHandler_ID  16
#define MCI0_IrqHandler_ID    17
#define TWI0_IrqHandler_ID    18
#define TWI1_IrqHandler_ID    19
#define SPI0_IrqHandler_ID    20
#define SSC0_IrqHandler_ID    21
#define TC0_IrqHandler_ID     22
#define TC1_IrqHandler_ID     23
#define TC2_IrqHandler_ID     24
#define PWM_IrqHandler_ID     25
#define ADCC0_IrqHandler_ID   26
#define ADCC1_IrqHandler_ID   27
#define HDMA_IrqHandler_ID    28
#define UDPD_IrqHandler_ID    29

/***************************************************************************/
/*                 P R O T O T Y P E S                                     */
/***************************************************************************/
void tn_irq_init (void);
int tn_irq_install (TN_IRQ_ID   id,
                    TN_IRQ_PRIO prio,
                    void (*irq_func)(void));

#endif /* !__TN_PORT_SAM3_H__ && TN_ARCH_CM3 && TN_PORT_SAM3 */
/*** EOF ***/
